@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2021 Arnaud Belcour - Inria Dyliss
+# Copyright (C) 2018-2022 Arnaud Belcour - Inria Dyliss
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -24,7 +24,6 @@ Create PathoLogic input files:
 import csv
 import logging
 import os
-import sys
 
 from Bio import SeqIO
 from gffutils.iterators import DataIterator
@@ -75,7 +74,7 @@ def check_input_and_existing_pgdb(run_ids, input_folder, output_folder, number_c
         list: input IDs for BioPAX/flat files creation
     """
     # Check if there are files/folders inside the input folder.
-    # And remove hidden folder/file (beginning with '.').
+    # And do not use hidden folder/file (beginning with '.').
     species_folders = [species_folder for species_folder in os.listdir(input_folder) if not species_folder.startswith('.')]
     if len(species_folders) == 0:
         logger.critical("No folder containing genbank/gff file. In {0} you must have sub-folders containing Genbank/GFF file.".format(input_folder))
@@ -128,6 +127,7 @@ def check_input_and_existing_pgdb(run_ids, input_folder, output_folder, number_c
 
     # Take run_ids and remove folder with error (with the intersection with check_species_folders) and if there is already present output.
     clean_run_ids = set(run_ids).intersection(set(check_species_folders))
+
     if output_folder:
         if os.path.exists(output_folder):
             if os.path.isdir(output_folder):
@@ -330,6 +330,10 @@ def extract_taxon_id(run_folder, pgdb_id, taxon_id, taxon_file):
                     if codon_table is not None:
                         taxon_datas['codon_table'] = codon_table
 
+                if 'reference_pgdb' in data:
+                    if data['reference_pgdb'] != '':
+                        taxon_datas['reference_pgdbs'] = data['reference_pgdb'].split(',')
+
     if pgdb_id not in known_species and taxon_id == '':
         logger.critical('Missing pgdb ID for {0} in {1}.'.format(pgdb_id, taxon_id_path))
         return True, None, None
@@ -474,8 +478,7 @@ def create_flats_and_lisp(run_folder, taxon_file):
                     if os.path.exists(fasta_path):
                         pf_fasta = fasta_species_name
                 if not pf_fasta:
-                    logger.critical('No fasta file (.fasta or .fsa) with the Pathologic file of {0}'.format(pgdb_id))
-                    return None
+                    logger.critical('No fasta file (.fasta or .fsa) with the Pathologic file of {0}, this could lead to warnings in Pathway Tools.'.format(pgdb_id))
 
         taxon_error, taxon_id, taxon_datas = extract_taxon_id(run_folder, pgdb_id, taxon_id, taxon_file)
 
@@ -490,6 +493,9 @@ def create_flats_and_lisp(run_folder, taxon_file):
         organism_writer.writerow(['STORAGE', "FILE"])
         organism_writer.writerow(['NCBI-TAXON-ID', taxon_id])
         organism_writer.writerow(['NAME', species_name])
+        if 'reference_pgdbs' in taxon_datas:
+            for reference_pgdb in taxon_datas['reference_pgdbs']:
+                organism_writer.writerow(['REF-ORGID', reference_pgdb])
 
     # Create the genetic-elements dat file.
     with open(genetic_dat, 'w', encoding='utf-8') as genetic_file:
@@ -630,16 +636,16 @@ def pwt_input_files(run_folder, taxon_file):
     error_found = False
     missing_string = ''
     if required_files.issubset(files_in):
-        missing_string = 'no missing files'
+        missing_string = 'No missing files'
     else:
-        missing_string = 'missing {0}'.format('; '.join(required_files.difference(files_in))) + '. Inputs file created for {0}'.format(species_folder)
+        missing_string = 'Missing {0}'.format('; '.join(required_files.difference(files_in))) + '. Inputs file created for {0}'.format(species_folder)
         check_datas_lisp = create_flats_and_lisp(run_folder, taxon_file)
         if check_datas_lisp is None:
-            logger.critical('Error with the creation of input files of {0}.'.format(run_folder))
+            logger.critical('|Input Check|{0}| Error with the creation of input files of {1}.'.format(species_folder, run_folder))
             error_found = True
             return error_found
 
-    logger.info('Checking inputs for {0}: {1}.'.format(species_folder, missing_string))
+    logger.info('|Input Check|{0}| {1}'.format(species_folder, missing_string))
 
     return error_found
 
@@ -661,7 +667,8 @@ def create_only_flat_lisp(pgdbs_folder_path, tmp_folder):
             pgdb_id = species_pgdb[:-3]
             pgdb_pathname = os.path.join(tmp_folder, pgdb_id)
             tmp_pgdb_path = os.path.join(tmp_folder, pgdb_id)
-            os.mkdir(tmp_pgdb_path)
+            if not os.path.exists(tmp_pgdb_path):
+                os.mkdir(tmp_pgdb_path)
             lisp_pathname = os.path.join(pgdb_pathname, 'flat_files_creation.lisp')
             check_lisp_file = create_flat_creation_script(pgdb_id, lisp_pathname)
             if not check_lisp_file:
